@@ -1,34 +1,20 @@
 /*
- * Copyright (C) 2013  David Edmundson <davidedmundson@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2013 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "persondatatests.h"
 
-#include <QtTest>
-#include <QFile>
-#include <QTemporaryFile>
+#include <QTest>
 
 //private includes
 #include "personmanager_p.h"
-#include "personpluginmanager_p.h"
 
 //public kpeople includes
+#include <QSignalSpy>
 #include <persondata.h>
+#include <personpluginmanager.h>
 
 #include "fakecontactsource.h"
 
@@ -95,7 +81,9 @@ void PersonDataTests::loadPerson()
     QCOMPARE(person.personUri(), QStringLiteral("kpeople://1"));
 
     //convert to set as order is not important
-    QCOMPARE(person.allEmails().toSet(), QSet<QString>() << QStringLiteral("contact2@example.com") << QStringLiteral("contact3@example.com"));
+    const QStringList allEmails = person.allEmails();
+    const QSet<QString> allEmailsSet(allEmails.begin(), allEmails.end());
+    QCOMPARE(allEmailsSet, QSet<QString>() << QStringLiteral("contact2@example.com") << QStringLiteral("contact3@example.com"));
 }
 
 void PersonDataTests::contactChanged()
@@ -120,3 +108,16 @@ void PersonDataTests::nullPerson()
     PersonData invalidPerson(QStringLiteral());
     QVERIFY(!invalidPerson.isValid());
 }
+
+void PersonDataTests::removeContact()
+{
+    PersonData person(QStringLiteral("fakesource://contact1"));
+
+    QCOMPARE(person.allEmails().at(0), QStringLiteral("contact1@example.com"));
+
+    QSignalSpy spy(&person, &PersonData::dataChanged);
+    m_source->remove(person.personUri());
+    QCOMPARE(spy.count(), 1);
+
+    QCOMPARE(person.name(), QString());
+}
