@@ -1,23 +1,11 @@
 /*
-    Copyright (C) 2013  Franck Arrecot <franck.arrecot@gmail.com>
+    SPDX-FileCopyrightText: 2013 Franck Arrecot <franck.arrecot@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef MERGE_CONTACT_WIDGET_H
-#define MERGE_CONTACT_WIDGET_H
+#ifndef MERGE_CONTACTS_WIDGET_H
+#define MERGE_CONTACTS_WIDGET_H
 
 #include "abstractpersondetailswidget.h"
 
@@ -59,4 +47,4 @@ private:
     QList< QPair<QPersistentModelIndex, PersonPresentationWidget *> > m_listMergeContacts;
 };
 
-#endif // MERGE_CONTACT_WIDGET_H
+#endif // MERGE_CONTACTS_WIDGET_H
